==> mx-welcome_24.12.03.tar.xz: mx-welcome/translations/mx-welcome_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="64"/>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>MX Welcome</source>
        <translation>MX Dámosche a benvida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Quit application</source>
        <translation>Saír do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>About this application</source>
        <translation>Sobre esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Welcome</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Install MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="510"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Axustes (Panel, etc...)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="536"/>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="568"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="600"/>
        <source>Users Manual</source>
        <translation>Manual do usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="626"/>
        <source>FAQ</source>
        <translation>Preguntas e Respostas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="652"/>
        <source>Tour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="674"/>
        <source>Popular Apps</source>
        <translation>Aplicativos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="700"/>
        <source>Contribute</source>
        <translation>Contribuír</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <source>Forums</source>
        <translation>Forums</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="790"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="892"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;meta charset=&quot;utf-8&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
hr { height: 1px; border-width: 0; }
li.unchecked::marker { content: &quot;\2610&quot;; }
li.checked::marker { content: &quot;\2612&quot;; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:10.5pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="923"/>
        <source>SHORT SYSTEM REPORT:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="798"/>
        <source>DESKTOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="815"/>
        <source>Quick-System-Info Full Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="825"/>
        <source>Terms of Use</source>
        <translation>Termos de uso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="845"/>
        <source>The name “MX Linux” is covered by Linux Foundation Sublicense No. 20140605-0483. We develop software that is covered by a free license that can be examined in the Wiki list. We also include software developed by others that is under a free license.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <source>MX VERSION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="862"/>
        <source>DEBIAN VERSION:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="869"/>
        <source>SUPPORTED UNTIL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="939"/>
        <source>Show this dialog at start up</source>
        <translation>Amosar esta lapela ao iniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>User demo, password:</source>
        <translation>Usuario demo, contrasinal:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Superuser root, password:</source>
        <translation>Superusuario, contrasinal:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="355"/>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;%1 &amp;quot;%2&amp;quot;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>About MX Welcome</source>
        <translation>Sobre MX Dámosche a benvida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Version: </source>
        <translation>Versión</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Programa para amosar unha pantalla de benvida no MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licenza</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Rexistro dos cambios</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Cerrar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as normal user.</source>
        <translation type="vanished">Dbeeb executar este programa como usuario normal.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>This tool displays a welcome screen with two tabs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Start with About tab selected. The About tab provides basic information about the current MX Linux version, the user&apos;s hardware, and access to a full system report.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Run a test mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>You must run this program as normal user.</source>
        <translation type="unfinished">Dbeeb executar este programa como usuario normal.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>License</source>
        <translation type="unfinished">Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <location filename="../about.cpp" line="50"/>
        <source>Changelog</source>
        <translation type="unfinished">Rexistro dos cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Cerrar</translation>
    </message>
</context>
</TS>

==> mx-welcome_24.12.04.tar.xz: mx-welcome/translations/mx-welcome_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="68"/>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>MX Welcome</source>
        <translation>MX Dámosche a benvida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Quit application</source>
        <translation>Saír do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>About this application</source>
        <translation>Sobre esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Welcome</source>
        <translation>Benvido</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Install MX Linux</source>
        <translation>Instalar MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="510"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Axustes (Panel, etc...)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="536"/>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="568"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="600"/>
        <source>Users Manual</source>
        <translation>Manual do usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="626"/>
        <source>FAQ</source>
        <translation>Preguntas e Respostas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="652"/>
        <source>Tour</source>
        <translation>Visita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="674"/>
        <source>Popular Apps</source>
        <translation>Aplicativos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="700"/>
        <source>Contribute</source>
        <translation>Contribuír</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <source>Forums</source>
        <translation>Forums</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="790"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="892"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;meta charset=&quot;utf-8&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
hr { height: 1px; border-width: 0; }
li.unchecked::marker { content: &quot;\2610&quot;; }
li.checked::marker { content: &quot;\2612&quot;; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:10.5pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="923"/>
        <source>SHORT SYSTEM REPORT:</source>
        <translation>INFORME CURTO DO SISTEMA:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="798"/>
        <source>DESKTOP</source>
        <translation>ESCRITORIO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="815"/>
        <source>Quick-System-Info Full Report</source>
        <translation>Informe completo de Quick-System-Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="825"/>
        <source>Terms of Use</source>
        <translation>Termos de uso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="845"/>
        <source>The name “MX Linux” is covered by Linux Foundation Sublicense No. 20140605-0483. We develop software that is covered by a free license that can be examined in the Wiki list. We also include software developed by others that is under a free license.</source>
        <translation>O nome &quot;MX Linux&quot; está cuberto pola sublicenza da Linux Foundation No. 20140605-0483. Desenvolvemos software que está cuberto por unha licenza libre que pode ser examinada na lista da Wiki. Tamén incluímos software desenvolvido por outros que está baixo unha licenza libre.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <source>MX VERSION</source>
        <translation>Versión MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="862"/>
        <source>DEBIAN VERSION:</source>
        <translation>DEBIAN VERSIÓN:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="869"/>
        <source>SUPPORTED UNTIL:</source>
        <translation>SOPORTADO ATÉ:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="939"/>
        <source>Show this dialog at start up</source>
        <translation>Amosar esta lapela ao iniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>User demo, password:</source>
        <translation>Usuario demo, contrasinal:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Superuser root, password:</source>
        <translation>Superusuario, contrasinal:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="205"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;%1 &amp;quot;%2&amp;quot;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>About MX Welcome</source>
        <translation>Sobre MX Dámosche a benvida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>Version: </source>
        <translation>Versión</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Programa para amosar unha pantalla de benvida no MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licenza</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Rexistro dos cambios</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Cerrar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as normal user.</source>
        <translation type="vanished">Dbeeb executar este programa como usuario normal.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>This tool displays a welcome screen with two tabs.</source>
        <translation>Esta ferramenta mostra unha pantalla de benvida con dúas lapelas.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Start with About tab selected. The About tab provides basic information about the current MX Linux version, the user&apos;s hardware, and access to a full system report.</source>
        <translation>Comeza coa lapela &quot;Sobre&quot; seleccionada. A lapela &quot;Sobre&quot; proporciona información básica sobre a versión actual de MX Linux, o hardware do usuario e acceso a un informe completo do sistema.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Run a test mode.</source>
        <translation>Executar un modo de proba.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>You must run this program as normal user.</source>
        <translation type="unfinished">Dbeeb executar este programa como usuario normal.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="61"/>
        <source>License</source>
        <translation type="unfinished">Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="62"/>
        <location filename="../about.cpp" line="72"/>
        <source>Changelog</source>
        <translation type="unfinished">Rexistro dos cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="85"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Cerrar</translation>
    </message>
</context>
</TS>
